pm4py.evaluation.generalization.variants package
================================================

Submodules
----------

pm4py.evaluation.generalization.variants.token\_based module
------------------------------------------------------------

.. automodule:: pm4py.evaluation.generalization.variants.token_based
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.evaluation.generalization.variants
   :members:
   :undoc-members:
   :show-inheritance:
